#ifndef NT2_INCLUDE_FUNCTIONS_MAXNUM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAXNUM_HPP_INCLUDED

#include <nt2/ieee/include/functions/maxnum.hpp>

#endif
